pub struct SFrameFDE {
pub func_start_address: i32,
pub func_size: u32,
pub func_start_fre_off: u32,
pub func_num_fres: u32,
pub func_info: SFrameFDEInfo,
}Expand description
Fields
func_start_address: i32Signed 32-bit integral field denoting the virtual memory address of the described function.
func_size: u32Unsigned 32-bit integral field specifying the size of the function in bytes.
func_start_fre_off: u32Unsigned 32-bit integral field specifying the offset in bytes of the function’s first SFrame FRE in the SFrame section.
func_num_fres: u32Unsigned 32-bit integral field specifying the total number of SFrame FREs used for the function.
func_info: SFrameFDEInfoThe SFrame FDE info word. See The SFrame FDE info word.
Implementations
Sourceimpl SFrameFDE
impl SFrameFDE
Sourcepub fn get_pc(&self, section: &SFrameSection<'_>) -> u64
pub fn get_pc(&self, section: &SFrameSection<'_>) -> u64
Compute pc of the function
Sourcepub fn iter_fre<'a>(
&'a self,
section: &'a SFrameSection<'a>,
) -> SFrameFREIterator<'a>
pub fn iter_fre<'a>( &'a self, section: &'a SFrameSection<'a>, ) -> SFrameFREIterator<'a>
Iterate FRE entries
Sourcepub fn find_fre(
&self,
section: &SFrameSection<'_>,
pc: u64,
) -> SFrameResult<Option<SFrameFRE>>
pub fn find_fre( &self, section: &SFrameSection<'_>, pc: u64, ) -> SFrameResult<Option<SFrameFRE>>
Find FRE entry by pc