SFrameFDEType

Enum SFrameFDEType 

pub enum SFrameFDEType {
    Default,
    Flex,
}
Variants



Default

SFRAME_FDE_TYPE_DEFAULT The default FDE type. CFA is recovered using the Stack Pointer (SP) or Frame Pointer (FP) plus a signed offset. Return Address (RA) and Frame Pointer (FP) are recovered using the CFA plus a signed offset (or a fixed register for specific architectures like s390x). The variable-length array of bytes trailing each SFrame FRE are interpreted according to the ABI/arch-specific rules for the target architecture. More details in Default FDE Type Interpretation.



Flex

SFRAME_FDE_TYPE_FLEX The flexible FDE type. Used for complex cases such as stack realignment (DRAP), non-standard CFA base registers, or when RA/FP recovery requires dereferencing or non-CFA base registers. The variable-length array of bytes may be interpreted as pairs of Control Data and Offset Data (or Padding Data), allowing for complex recovery rules (e.g., DRAP on AMD64, Stack Realignment). More details in Flexible FDE Type Interpretation.